"use strict";(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[8238,8107,5663,273],{98107:function(E,A,f){f.d(A,{YM:function(){return b},ap:function(){return c},bS:function(){return O}});var c={DALLE:"gizmo_6BCNM3ELMB8TALHWU0kav1gg",CODE_COMPANION:"gizmo_PgeEdpiH5xhqtjZtnODS9byu",BROWSER:"gizmo_yTzFvQfxGJsJhmcAQGFFzbUN",NEW_GPT:"8b251995-a2cf-49cf-b383-6424267676f7",LACROIX_GENERATOR:"64018dfa-1c06-4667-a32d-3035a5e74ad1",PNG_PANTHER:"2f38f2b8-e925-4f26-9770-b9dace18b5be",LANGUAGE_PRACTICE:"86eff182-d5d4-4391-aa60-0c0c54df8060",DALLE_NAVIGATOR:"0b1a5d0f-4a99-4421-a02c-cce08b7897c6",COPY_PROOFREADER:"4ea96bef-bb1c-483e-81f7-77949de1a37f",DALLE_8BIT:"495fb028-c966-4a53-8b0a-8cbc91739b04",DUNGEON_MASTER:"4559c961-8a15-49b6-bc3e-586f105c010c",SLIDEMASTER:"4f55d33f-3cec-442b-909e-a70f5c938767",POSTERIZER:"9cb8c072-dc05-4288-92a8-c59a27e59e74",ASTROLOGY:"f450b8e4-2baa-4c81-9f1a-ddfd0f1ef1ac",FANTASY_FOOTBALL:"37fb82bd-b9b5-4244-9c01-2b5d6916473f",JEOPARDY:"ee8fddfc-52b2-484d-839b-288f4bf2f7e2"},O=[c.DALLE,c.CODE_COMPANION,c.BROWSER],b=[c.LACROIX_GENERATOR,c.PNG_PANTHER,c.LANGUAGE_PRACTICE,c.DALLE_NAVIGATOR,c.COPY_PROOFREADER,c.DALLE_8BIT,c.DUNGEON_MASTER,c.SLIDEMASTER,c.POSTERIZER,c.ASTROLOGY,c.FANTASY_FOOTBALL,c.JEOPARDY]}}]);