(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[2758],{36232:function(n,t,u){(window.__NEXT_P=window.__NEXT_P||[]).push(["/aip/[pluginId]/oauth/callback",function(){return u(80339)}])},80339:function(n,t,u){"use strict";u.r(t),u.d(t,{__N_SSP:function(){return l},default:function(){return p}});var c=u(21722),e=u(39324),i=u(38104),o=u(35250),r=u(95137),s=u(60554),a=u(70079),l=!0;function p(n){return(0,o.jsx)(f,(0,e._)({},n))}function f(n){var t=n.pluginId,u=n.code,e=n.state,l=(0,s.useRouter)();return(0,a.useEffect)(function(){function n(){return(n=(0,c._)(function(){var n;return(0,i.Jh)(this,function(c){switch(c.label){case 0:n="".concat(window.location.origin,"/aip/").concat(t,"/oauth/callback"),c.label=1;case 1:return c.trys.push([1,3,,4]),[4,r.ZP.pluginOauthCallback(t,u,n,e)];case 2:return c.sent(),l.push("/?model=gpt-4-plugins&loginAip=".concat(t,"&loginSuccess=true")),[3,4];case 3:return console.error(c.sent()),l.push("/?model=gpt-4-plugins&loginAip=".concat(t,"&loginSuccess=false")),[3,4];case 4:return[2]}})})).apply(this,arguments)}!function(){n.apply(this,arguments)}()},[t,u,e,l]),(0,o.jsx)("div",{})}}},function(n){n.O(0,[9774,2888,179],function(){return n(n.s=36232)}),_N_E=n.O()}]);