"use strict";(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[6321,8107,8238,5663,273],{98107:function(e,c,a){a.d(c,{YM:function(){return E},ap:function(){return f},bS:function(){return n}});var f={DALLE:"gizmo_6BCNM3ELMB8TALHWU0kav1gg",CODE_COMPANION:"gizmo_PgeEdpiH5xhqtjZtnODS9byu",BROWSER:"gizmo_yTzFvQfxGJsJhmcAQGFFzbUN",NEW_GPT:"8b251995-a2cf-49cf-b383-6424267676f7",LACROIX_GENERATOR:"64018dfa-1c06-4667-a32d-3035a5e74ad1",PNG_PANTHER:"2f38f2b8-e925-4f26-9770-b9dace18b5be",LANGUAGE_PRACTICE:"86eff182-d5d4-4391-aa60-0c0c54df8060",DALLE_NAVIGATOR:"0b1a5d0f-4a99-4421-a02c-cce08b7897c6",COPY_PROOFREADER:"4ea96bef-bb1c-483e-81f7-77949de1a37f",DALLE_8BIT:"495fb028-c966-4a53-8b0a-8cbc91739b04",DUNGEON_MASTER:"4559c961-8a15-49b6-bc3e-586f105c010c",SLIDEMASTER:"4f55d33f-3cec-442b-909e-a70f5c938767",POSTERIZER:"9cb8c072-dc05-4288-92a8-c59a27e59e74",ASTROLOGY:"f450b8e4-2baa-4c81-9f1a-ddfd0f1ef1ac",FANTASY_FOOTBALL:"37fb82bd-b9b5-4244-9c01-2b5d6916473f",JEOPARDY:"ee8fddfc-52b2-484d-839b-288f4bf2f7e2"},n=[f.DALLE,f.CODE_COMPANION,f.BROWSER],E=[f.LACROIX_GENERATOR,f.PNG_PANTHER,f.LANGUAGE_PRACTICE,f.DALLE_NAVIGATOR,f.COPY_PROOFREADER,f.DALLE_8BIT,f.DUNGEON_MASTER,f.SLIDEMASTER,f.POSTERIZER,f.ASTROLOGY,f.FANTASY_FOOTBALL,f.JEOPARDY]},83023:function(e,c,a){a.d(c,{$:function(){return A},o:function(){return b}});var f=a(35250),n=a(19841),E=a(88327),d=a(69385);function A(e){var c=e.gizmo,a=e.className;return(0,f.jsx)("div",{className:(0,n.default)("gizmo-shadow-stroke rounded-full",a),children:null!=c?(0,f.jsx)("img",{src:c.profile_pic_permalink,alt:c.name,className:"overflow-hidden rounded-full object-cover"}):(0,f.jsx)("div",{className:"flex h-full items-center justify-center rounded-full bg-black text-white",children:(0,f.jsx)(E.nI,{className:"h-2/3 w-2/3"})})})}function s(e){var c=e.gizmoId,a=e.className,n=(0,d.b9)(c).data;return null==n?(0,f.jsx)("div",{className:a}):(0,f.jsx)(A,{gizmo:n,className:a})}function b(e){var c=e.gizmoId,a=e.className;return null==c?(0,f.jsx)(A,{gizmo:void 0,className:a}):(0,f.jsx)(s,{gizmoId:c,className:a})}}}]);