(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[5425],{63605:function(n,u,t){(window.__NEXT_P=window.__NEXT_P||[]).push(["/payments/success",function(){return t(1557)}])},1557:function(n,u,t){"use strict";t.r(u),t.d(u,{PAYMENTS_SUCCESS_URL:function(){return s},__N_SSP:function(){return r},default:function(){return _}});var c=t(35250),e=t(695),r=!0,s="/payments/success";function _(){return(0,c.jsx)(f,{})}function f(){return(0,c.jsx)(e.W,{})}}},function(n){n.O(0,[695,9774,2888,179],function(){return n(n.s=63605)}),_N_E=n.O()}]);