<!DOCTYPE html><html><head><meta charSet="utf-8"/><meta name="title" content="ChatGPT: Get instant answers, find inspiration, learn something new"/><meta name="keywords" content="ai chat,ai,chap gpt,chat gbt,chat gpt 3,chat gpt login,chat gpt website,chat gpt,chat gtp,chat openai,chat,chatai,chatbot gpt,chatg,chatgpt login,chatgpt,gpt chat,open ai,openai chat,openai chatgpt,openai"/><meta http-equiv="Content-Type" content="text/html; charset=utf-8"/><meta name="viewport" content="width=device-width, initial-scale=1"/><meta property="og:title" content="ChatGPT"/><meta property="og:url" content="https://chat.openai.com"/><link rel="manifest" href="/manifest.json"/><title>ChatGPT</title><meta property="og:site_name" content="ChatGPT"/><meta name="robots" content="noindex,nofollow"/><meta property="og:title" content="ChatGPT"/><meta property="og:decription" content="Shared via ChatGPT"/><meta property="og:image" content="https://chat.openai.com/images/chatgpt-share-og.png"/><meta name="next-head-count" content="14"/><link rel="apple-touch-icon" sizes="180x180" href="/apple-touch-icon.png"/><link rel="icon" type="image/png" sizes="32x32" href="/favicon-32x32.png"/><link rel="icon" type="image/png" sizes="16x16" href="/favicon-16x16.png"/><link rel="preconnect" href="{{api_prefix|safe}}"/><link rel="preload" href="/fonts/soehne/soehne-buch.woff2" as="font" crossorigin=""/><link rel="preload" href="/fonts/soehne/soehne-halbfett.woff2" as="font" crossorigin=""/><link rel="preload" href="/fonts/soehne/soehne-mono-buch.woff2" as="font" crossorigin=""/><link rel="preload" href="/fonts/soehne/soehne-mono-halbfett.woff2" as="font" crossorigin=""/><link rel="preload" href="/_next/static/css/f40b2ebfb8cc1614.css" as="style"/><link rel="stylesheet" href="/_next/static/css/f40b2ebfb8cc1614.css" data-n-g=""/><noscript data-n-css=""></noscript><script>window.__api_prefix='{{api_prefix|safe}}';window.onerror=function(){return !0;};</script><script defer="" nomodule="" src="/_next/static/chunks/polyfills-c67a75d1b6f99dc8.js"></script><script src="/_next/static/chunks/webpack-00de4b1a3c21b6d8.js" defer=""></script><script src="/_next/static/chunks/framework-10a404587b40544b.js" defer=""></script><script src="/_next/static/chunks/main-989cac6f6309d951.js" defer=""></script><script src="/_next/static/chunks/pages/app-1f71ef8cca5f3e9a.js" defer=""></script><script src="/_next/static/chunks/bd26816a-537855338b714f81.js" defer=""></script><script src="/_next/static/chunks/6199c948-28b15521c4eb1cf7.js" defer=""></script><script src="/_next/static/chunks/1f110208-24bf6c2e080e0308.js" defer=""></script><script src="/_next/static/chunks/2104-09304abac0293deb.js" defer=""></script><script src="/_next/static/chunks/1438-8d1de903270120c8.js" defer=""></script><script src="/_next/static/chunks/7985-7419f0f46b18b9d5.js" defer=""></script><script src="/_next/static/chunks/4137-447db6c53ca8543c.js" defer=""></script><script src="/_next/static/chunks/9441-b93d2e2ad8e95779.js" defer=""></script><script src="/_next/static/chunks/8937-f86d189206c4dbba.js" defer=""></script><script src="/_next/static/chunks/2357-96faabdfa8cc96a3.js" defer=""></script><script src="/_next/static/chunks/4099-9cd8db1fba82daf6.js" defer=""></script><script src="/_next/static/chunks/722-f4a61e9d1191da1c.js" defer=""></script><script src="/_next/static/chunks/2766-4b22cbefddaac9b3.js" defer=""></script><script src="/_next/static/chunks/9119-c2ab9bf5947373cf.js" defer=""></script><script src="/_next/static/chunks/pages/share/shareParams-c90f9822af7eabf2.js" defer=""></script><script src="/_next/static/VkDNisWOezhjENf61sgQl/buildManifest.js" defer=""></script><script src="/_next/static/VkDNisWOezhjENf61sgQl/ssgManifest.js" defer=""></script></head><body class="antialiased"><div id="__next"><script>!function(){try{var d=document.documentElement,c=d.classList;c.remove('light','dark');var e=localStorage.getItem('theme');if('system'===e||(!e&&true)){var t='(prefers-color-scheme: dark)',m=window.matchMedia(t);if(m.media!==t||m.matches){d.style.colorScheme = 'dark';c.add('dark')}else{d.style.colorScheme = 'light';c.add('light')}}else if(e){c.add(e|| '')}if(e==='light'||e==='dark')d.style.colorScheme=e}catch(e){}}()</script><div class="absolute left-0 right-0 top-0 z-[2]"></div></div><script id="__NEXT_DATA__" type="application/json">{{props|tojson|safe}}</script><script>if('serviceWorker' in navigator){window.addEventListener('load',function(){navigator.serviceWorker.register('/service-worker.js',{scope:'/'}).then(function(reg){console.log('ServiceWorker registration successful with scope: ',reg.scope);},function(e){console.log('ServiceWorker registration failed: ',e);});});}</script></body></html>