(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[4191],{90560:function(n,t,u){(window.__NEXT_P=window.__NEXT_P||[]).push(["/auth/ext_callback",function(){return u(83929)}])},83929:function(n,t,u){"use strict";u.r(t),u.d(t,{default:function(){return o}});var e=u(35250),r=u(12155),c=u(60554),f=u(70079);function o(){return(0,e.jsx)(a,{})}function a(){var n=(0,c.useRouter)().query.next,t="/auth/ext_callback_refresh?next="+encodeURIComponent("string"==typeof n&&n.startsWith("/")?n:"/");return(0,f.useEffect)(function(){(0,r.signIn)("auth0",{callbackUrl:t||"/"})},[]),null}}},function(n){n.O(0,[9774,2888,179],function(){return n(n.s=90560)}),_N_E=n.O()}]);