(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[5465],{39104:function(n,u,t){(window.__NEXT_P=window.__NEXT_P||[]).push(["/status",function(){return t(14400)}])},14400:function(n,u,t){"use strict";t.r(u),t.d(u,{default:function(){return c}});var _=t(35250),r=t(61564);function c(){return(0,_.jsx)(r.Z,{})}}},function(n){n.O(0,[1564,9774,2888,179],function(){return n(n.s=39104)}),_N_E=n.O()}]);