(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[7825],{79242:function(n,u,t){(window.__NEXT_P=window.__NEXT_P||[]).push(["/auth/logout",function(){return t(58193)}])},58193:function(n,u,t){"use strict";t.r(u),t.d(u,{__N_SSP:function(){return f},default:function(){return _}});var o=t(39324),i=t(35250),r=t(88809),c=t(12155),e=t(70079),f=!0;function _(n){return(0,i.jsx)(s,(0,o._)({},n))}function s(n){var u=n.federatedLogoutUri;return(0,e.useEffect)(function(){(0,c.signOut)({callbackUrl:u||window.location.origin})},[u]),(0,e.useEffect)(function(){(0,r.I)()},[]),null}}},function(n){n.O(0,[9774,2888,179],function(){return n(n.s=79242)}),_N_E=n.O()}]);