(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[4382],{24127:function(e,r,n){(window.__NEXT_P=window.__NEXT_P||[]).push(["/gizmo/g/[gizmoId]",function(){return n(32717)}])},32717:function(e,r,n){"use strict";n.r(r),n.d(r,{__N_SSP:function(){return s},default:function(){return a}});var u=n(35250),t=n(58069),o=n(60554),s=!0;function a(){var e=(0,o.useRouter)().query.gizmoId;return(0,u.jsx)("div",{children:(0,u.jsx)(t.h,{shortCode:e})})}},67:function(e,r,n){"use strict";n.d(r,{X:function(){return l},m:function(){return d}});var u=n(4337),t=n(35250),o=n(19841),s=n(9181),a=n.n(s);function i(){var e=(0,u._)(["rounded-full bg-black dark:bg-gray-100"]);return i=function(){return e},e}var l=n(21389).Z.div(i());function d(e){var r=e.className;return(0,t.jsx)(a(),{href:"/",shallow:!0,className:(0,o.default)("block h-8 w-8 cursor-pointer",r),children:(0,t.jsx)(l,{className:"h-full w-full"})})}},99805:function(e,r,n){"use strict";n.d(r,{QT:function(){return _},UA:function(){return h},i1:function(){return m},y4:function(){return p}});var u=n(39324),t=n(71209),o=n(4337),s=n(35250),a=n(47428),i=n(19841),l=n(21389),d=n(67273),c=n(45635);function f(){var e=(0,o._)(["sticky top-0 flex items-center justify-between z-10 h-14 bg-white/95 p-2 font-semibold dark:bg-gray-800/90 ",""]);return f=function(){return e},e}function m(e){var r=e.children,n=e.className,u=e.size;return(0,s.jsxs)("div",{className:(0,i.default)("relative flex-shrink-0 overflow-hidden","small"===u&&"rounded-sm","medium"===u&&"rounded-md","large"===u&&"rounded-lg","cover"===u&&"rounded-[38px]",n),children:[r,(0,s.jsx)("div",{className:(0,i.default)("absolute inset-0 shadow-[inset_0_0_0_1px_rgba(0,0,0,0.1)]","small"===u&&"rounded-sm","medium"===u&&"rounded-md","large"===u&&"rounded-lg","cover"===u&&"rounded-[38px]")})]})}var _=l.Z.div(f(),function(e){return e.$spaceForCollapsedSidebar&&"pl-12"});function h(e){return(0,s.jsx)(a.ck,(0,t._)((0,u._)({},e),{className:(0,i.default)("flex cursor-pointer gap-2 px-5 py-3 text-sm hover:bg-gray-100 focus:ring-0 dark:hover:bg-gray-800",e.disabled&&"pointer-events-none opacity-50",e.className)}))}function p(e){var r=(0,s.jsx)(d.z,(0,t._)((0,u._)({color:"neutral",size:"small"},e),{className:(0,i.default)("h-10 whitespace-nowrap rounded-lg border border-token-border-medium px-3 py-2 shadow-[0_1px_1px_0_rgba(0,0,0,0.08)] focus:ring-0",e.className)}));return null!=e.label?(0,s.jsx)(c.u,{side:"left",label:e.label,className:"h-fit w-fit",children:r}):r}}},function(e){e.O(0,[8682,9774,2888,179],function(){return e(e.s=24127)}),_N_E=e.O()}]);