(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[2555],{40567:function(n,t,e){(window.__NEXT_P=window.__NEXT_P||[]).push(["/payments/success-trial",function(){return e(18118)}])},18118:function(n,t,e){"use strict";e.r(t),e.d(t,{PAYMENTS_SUCCESS_URL:function(){return a},__N_SSP:function(){return f},default:function(){return o}});var u=e(35250),r=e(695),c=e(18719),s=e(73426),_=e(16920),i=e(70079),f=!0,a="/payments/success";function o(){return(0,u.jsx)(l,{})}function l(){return(0,i.useEffect)(function(){_.m9.logEvent("chatgpt_referral_trial_payment_success"),c.A.logEvent(s.M.chatgptReferralTrialPaymentSuccess)},[]),(0,u.jsx)(r.W,{isTrial:!0})}}},function(n){n.O(0,[695,9774,2888,179],function(){return n(n.s=40567)}),_N_E=n.O()}]);