(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[1905],{21451:function(n,t,u){(window.__NEXT_P=window.__NEXT_P||[]).push(["/auth/ext_callback_refresh",function(){return u(29420)}])},29420:function(n,t,u){"use strict";u.r(t),u.d(t,{__N_SSP:function(){return _},default:function(){return c}});var e=u(35250),r=u(60554),f=u(70079),_=!0;function c(){return(0,e.jsx)(i,{})}function i(){var n=(0,r.useRouter)(),t=n.query.next,u="string"==typeof t&&t.startsWith("/")?t:"/";return(0,f.useEffect)(function(){n.push(u)},[u,n]),null}}},function(n){n.O(0,[9774,2888,179],function(){return n(n.s=21451)}),_N_E=n.O()}]);