(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[3489],{223:function(n,t,u){(window.__NEXT_P=window.__NEXT_P||[]).push(["/account/upgrade",function(){return u(20717)}])},20717:function(n,t,u){"use strict";u.r(t),u.d(t,{__N_SSP:function(){return h},default:function(){return v}});var o=u(39324),e=u(35250),r=u(93683),a=u(88798),c=u(27986),i=u(21739),s=u(78931),l=u(18719),f=u(73426),d=u(60554),_=u(70079),h=!0;function v(n){return(0,e.jsx)(p,(0,o._)({},n))}function p(n){var t=n.user,u=n.isUserInCanPayGroup,o=n.serviceStatus,l=n.userCountry,f=n.cohort,h=n.allowBrowserStorage,v=(0,d.useRouter)(),p=(0,s.WY)(),C=(0,i.g)(function(n){return n.updateFlagValue});(0,_.useEffect)(function(){void 0!==u&&C("isUserInCanPayGroup",u)},[C,u]),(0,_.useEffect)(function(){(null==o?void 0:o.type)&&void 0!==p&&!p&&a.m.warning(o.message,{hasCloseButton:!0,duration:5})},[p,null==o?void 0:o.message,null==o?void 0:o.type]);var E={};void 0!==f&&f.length>0&&(E.email_cohort=f),(0,c.Z)("ChatGPT",t,h,E);var w=(0,_.useCallback)(function(){v.push("/")},[v]);return(0,e.jsx)(g,{cohort:f,userCountry:l,children:(0,e.jsx)(r.Z,{isOpen:!0,onClose:w})})}var g=function(n){var t=n.children,u=n.cohort,o=n.userCountry;return(0,_.useEffect)(function(){void 0!==u&&u.length>0&&l.A.logEvent(f.M.accountUpgradeFullpageLoaded,{content:"Email Cohort: ".concat(u),tags:["actual_location:".concat(o)]})},[u,o]),t}}},function(n){n.O(0,[8937,9774,2888,179],function(){return n(n.s=223)}),_N_E=n.O()}]);