(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[3468],{70908:function(n,u,t){(window.__NEXT_P=window.__NEXT_P||[]).push(["/account/cancel",function(){return t(81449)}])},81449:function(n,u,t){"use strict";t.r(u),t.d(u,{__N_SSP:function(){return r},default:function(){return _}});var c=t(35250),r=!0;function _(){return(0,c.jsx)(c.Fragment,{children:(0,c.jsx)("div",{})})}}},function(n){n.O(0,[9774,2888,179],function(){return n(n.s=70908)}),_N_E=n.O()}]);