"use strict";(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[4184,8107,8238,5663,273],{82920:function(n,e){function r(n,e){if(e)return n;throw Error("Unhandled discriminated union member: "+JSON.stringify(n))}e.vE=r,e.ZP=r},72201:function(n,e,r){r.d(e,{Z:function(){return f}});var t=r(24421),u=r(28734),a=r(51516);function c(n){(0,a.Z)(1,arguments);var e=(0,u.Z)(n);return e.setHours(0,0,0,0),e}function f(n,e){(0,a.Z)(2,arguments);var r=c(n),u=c(e);return Math.round((r.getTime()-(0,t.Z)(r)-(u.getTime()-(0,t.Z)(u)))/864e5)}},26430:function(n,e,r){r.d(e,{Z:function(){return a}});var t=r(28734),u=r(51516);function a(n,e){return(0,u.Z)(2,arguments),(0,t.Z)(n).getTime()-(0,t.Z)(e).getTime()}},84913:function(n,e,r){r.d(e,{Z:function(){return a}});var t=r(28734),u=r(51516);function a(){return function(n){(0,u.Z)(1,arguments);var e=(0,t.Z)(n);return e.setHours(23,59,59,999),e}(Date.now())}},44043:function(n,e,r){r.d(e,{Z:function(){return a}});var t=r(28734),u=r(51516);function a(n){return(0,u.Z)(1,arguments),(0,t.Z)(n).getMonth()}},82187:function(n,e,r){r.d(e,{Z:function(){return a}});var t=r(28734),u=r(51516);function a(n){return(0,u.Z)(1,arguments),(0,t.Z)(n).getFullYear()}},69262:function(n,e,r){r.d(e,{Z:function(){return a}});var t=r(28734),u=r(51516);function a(n){return(0,u.Z)(1,arguments),function(n,e){(0,u.Z)(2,arguments);var r=(0,t.Z)(n),a=(0,t.Z)(e);return r.getFullYear()===a.getFullYear()}(n,Date.now())}},98107:function(n,e,r){r.d(e,{YM:function(){return a},ap:function(){return t},bS:function(){return u}});var t={DALLE:"gizmo_6BCNM3ELMB8TALHWU0kav1gg",CODE_COMPANION:"gizmo_PgeEdpiH5xhqtjZtnODS9byu",BROWSER:"gizmo_yTzFvQfxGJsJhmcAQGFFzbUN",NEW_GPT:"8b251995-a2cf-49cf-b383-6424267676f7",LACROIX_GENERATOR:"64018dfa-1c06-4667-a32d-3035a5e74ad1",PNG_PANTHER:"2f38f2b8-e925-4f26-9770-b9dace18b5be",LANGUAGE_PRACTICE:"86eff182-d5d4-4391-aa60-0c0c54df8060",DALLE_NAVIGATOR:"0b1a5d0f-4a99-4421-a02c-cce08b7897c6",COPY_PROOFREADER:"4ea96bef-bb1c-483e-81f7-77949de1a37f",DALLE_8BIT:"495fb028-c966-4a53-8b0a-8cbc91739b04",DUNGEON_MASTER:"4559c961-8a15-49b6-bc3e-586f105c010c",SLIDEMASTER:"4f55d33f-3cec-442b-909e-a70f5c938767",POSTERIZER:"9cb8c072-dc05-4288-92a8-c59a27e59e74",ASTROLOGY:"f450b8e4-2baa-4c81-9f1a-ddfd0f1ef1ac",FANTASY_FOOTBALL:"37fb82bd-b9b5-4244-9c01-2b5d6916473f",JEOPARDY:"ee8fddfc-52b2-484d-839b-288f4bf2f7e2"},u=[t.DALLE,t.CODE_COMPANION,t.BROWSER],a=[t.LACROIX_GENERATOR,t.PNG_PANTHER,t.LANGUAGE_PRACTICE,t.DALLE_NAVIGATOR,t.COPY_PROOFREADER,t.DALLE_8BIT,t.DUNGEON_MASTER,t.SLIDEMASTER,t.POSTERIZER,t.ASTROLOGY,t.FANTASY_FOOTBALL,t.JEOPARDY]},67:function(n,e,r){r.d(e,{X:function(){return i},m:function(){return d}});var t=r(4337),u=r(35250),a=r(19841),c=r(9181),f=r.n(c);function o(){var n=(0,t._)(["rounded-full bg-black dark:bg-gray-100"]);return o=function(){return n},n}var i=r(21389).Z.div(o());function d(n){var e=n.className;return(0,u.jsx)(f(),{href:"/",shallow:!0,className:(0,a.default)("block h-8 w-8 cursor-pointer",e),children:(0,u.jsx)(i,{className:"h-full w-full"})})}},99805:function(n,e,r){r.d(e,{QT:function(){return E},UA:function(){return A},i1:function(){return b},y4:function(){return _}});var t=r(39324),u=r(71209),a=r(4337),c=r(35250),f=r(47428),o=r(19841),i=r(21389),d=r(67273),l=r(45635);function s(){var n=(0,a._)(["sticky top-0 flex items-center justify-between z-10 h-14 bg-white/95 p-2 font-semibold dark:bg-gray-800/90 ",""]);return s=function(){return n},n}function b(n){var e=n.children,r=n.className,t=n.size;return(0,c.jsxs)("div",{className:(0,o.default)("relative flex-shrink-0 overflow-hidden","small"===t&&"rounded-sm","medium"===t&&"rounded-md","large"===t&&"rounded-lg","cover"===t&&"rounded-[38px]",r),children:[e,(0,c.jsx)("div",{className:(0,o.default)("absolute inset-0 shadow-[inset_0_0_0_1px_rgba(0,0,0,0.1)]","small"===t&&"rounded-sm","medium"===t&&"rounded-md","large"===t&&"rounded-lg","cover"===t&&"rounded-[38px]")})]})}var E=i.Z.div(s(),function(n){return n.$spaceForCollapsedSidebar&&"pl-12"});function A(n){return(0,c.jsx)(f.ck,(0,u._)((0,t._)({},n),{className:(0,o.default)("flex cursor-pointer gap-2 px-5 py-3 text-sm hover:bg-gray-100 focus:ring-0 dark:hover:bg-gray-800",n.disabled&&"pointer-events-none opacity-50",n.className)}))}function _(n){var e=(0,c.jsx)(d.z,(0,u._)((0,t._)({color:"neutral",size:"small"},n),{className:(0,o.default)("h-10 whitespace-nowrap rounded-lg border border-token-border-medium px-3 py-2 shadow-[0_1px_1px_0_rgba(0,0,0,0.08)] focus:ring-0",n.className)}));return null!=n.label?(0,c.jsx)(l.u,{side:"left",label:n.label,className:"h-fit w-fit",children:e}):e}}}]);