(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[6529],{84621:function(n,e,t){(window.__NEXT_P=window.__NEXT_P||[]).push(["/invite/accepted",function(){return t(71655)}])},71655:function(n,e,t){"use strict";t.r(e),t.d(e,{__N_SSP:function(){return _},default:function(){return h}});var u=t(21722),r=t(38104),c=t(35250),s=t(56817),i=t(1821),f=t(95137),a=t(68993),o=t(60554),l=t(70079),_=!0;function h(){var n=(0,o.useRouter)();return(0,l.useEffect)(function(){if(n){var e;(e=(0,u._)(function(){var e,t;return(0,r.Jh)(this,function(u){switch(u.label){case 0:return u.trys.push([0,2,,3]),[4,f.ZP.getCheckoutLink()];case 1:return e=u.sent(),n.replace(e.url),[3,3];case 2:if((t=u.sent())instanceof a.Q0&&(null==t?void 0:t.message)==s.D7.ALREADY_PAID)return n.push("/"),[2];return[3,3];case 3:return[2]}})}),function(){return e.apply(this,arguments)})()}},[n]),(0,c.jsx)("div",{className:"flex h-full w-full items-center justify-center",children:(0,c.jsx)(i.Z,{})})}}},function(n){n.O(0,[9774,2888,179],function(){return n(n.s=84621)}),_N_E=n.O()}]);