"use strict";(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[6786],{54655:function(t,n,e){e.d(n,{Ny3:function(){return o}});var r=e(50913);function o(t){return(0,r.w_)({tag:"svg",attr:{viewBox:"0 0 24 24",strokeWidth:"2",stroke:"currentColor",fill:"none",strokeLinecap:"round",strokeLinejoin:"round"},child:[{tag:"desc",attr:{},child:[]},{tag:"path",attr:{stroke:"none",d:"M0 0h24v24H0z",fill:"none"}},{tag:"path",attr:{d:"M5 9h14m-14 6h14"}}]})(t)}}}]);