(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[7371],{44328:function(n,u,t){(window.__NEXT_P=window.__NEXT_P||[]).push(["/gizmo",function(){return t(15673)}])},15673:function(n,u,t){"use strict";t.r(u),t.d(u,{__N_SSP:function(){return r},default:function(){return e}});var _=t(35250),r=!0;function e(){return(0,_.jsx)(_.Fragment,{})}}},function(n){n.O(0,[9774,2888,179],function(){return n(n.s=44328)}),_N_E=n.O()}]);